==> indac.db_2.2.5.tar.gz: indac.db/man/indac_dbconn.Rd <==
\name{indac_dbconn}

\alias{indac_dbconn}
\alias{indac_dbfile}
\alias{indac_dbschema}
\alias{indac_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  indac_dbconn()
  indac_dbfile()
  indac_dbschema(file="", show.indices=FALSE)
  indac_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{indac_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{indac_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{indac_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{indac_dbschema} prints the schema definition of the
  package annotation DB.

  \code{indac_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{indac_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{indac_dbfile}: a character string with the path to the
  package annotation DB.

  \code{indac_dbschema}: none (invisible \code{NULL}).

  \code{indac_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(indac_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by indac_dbconn() was created with:
  dbConnect(SQLite(), dbname=indac_dbfile(), cache_size=64000, synchronous=0)

  indac_dbschema()

  indac_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> indac.db_2.10.1.tar.gz: indac.db/man/indac_dbconn.Rd <==

\name{indac_dbconn}

\alias{indac_dbconn}
\alias{indac_dbfile}
\alias{indac_dbschema}
\alias{indac_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  indac_dbconn()
  indac_dbfile()
  indac_dbschema(file="", show.indices=FALSE)
  indac_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{indac_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{indac_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{indac_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{indac_dbschema} prints the schema definition of the
  package annotation DB.

  \code{indac_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{indac_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{indac_dbfile}: a character string with the path to the
  package annotation DB.

  \code{indac_dbschema}: none (invisible \code{NULL}).

  \code{indac_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(indac_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by indac_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=indac_dbfile(), cache_size=64000,
  synchronous=0)

  indac_dbschema()

  indac_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
